@@ -26,6 +26,7 @@
 #include "itemserializer_p.h"
 #include "itemserializerplugin.h"
 #include "servermanager.h"
+#include "tagfetchscope.h"
 #include <akonadi/private/xdgbasedirs_p.h>
 
 #include <QtCore/QDateTime>
@@ -445,8 +446,12 @@ QByteArray ProtocolHelper::itemFetchScopeToByteArray( const ItemFetchScope &fetc
     command += " " AKONADI_PARAM_REMOTEID " " AKONADI_PARAM_REMOTEREVISION;
   if ( fetchScope.fetchGid() )
     command += " GID";
-  if ( fetchScope.fetchTags() )
+  if ( fetchScope.fetchTags() ) {
     command += " TAGS";
+    if ( !fetchScope.tagFetchScope().fetchIdOnly() ) {
+      command += " " + ProtocolHelper::tagFetchScopeToByteArray( fetchScope.tagFetchScope() );
+    }
+  }
   if ( fetchScope.fetchVirtualReferences() )
     command += " VIRTREF";
   if ( fetchScope.fetchModificationTime() )
@@ -460,6 +465,41 @@ QByteArray ProtocolHelper::itemFetchScopeToByteArray( const ItemFetchScope &fetc
   return command;
 }
 
+QByteArray ProtocolHelper::tagFetchScopeToByteArray( const TagFetchScope &fetchScope )
+{
+  QByteArray command;
+
+  command += "(UID";
+  Q_FOREACH (const QByteArray &part, fetchScope.attributes()) {
+    command += ' ' + ProtocolHelper::encodePartIdentifier(ProtocolHelper::PartAttribute, part);
+  }
+  command += ")";
+  return command;
+}
+
+static Item::Flags convertFlags( const QList<QByteArray>& flags, ProtocolHelperValuePool *valuePool )
+{
+#if __cplusplus >= 201103L || defined(__GNUC__) || defined(__clang__)
+  // When the compiler supports thread-safe static initialization (mandated by the C++11 memory model)
+  // then use it to share the common case of a single-item set only containing the \SEEN flag.
+  // NOTE: GCC and clang has threadsafe static initialization for some time now, even without C++11.
+  if (flags.size() == 1 && flags.first() == "\\SEEN") {
+    static const Item::Flags sharedSeen = Item::Flags() << QByteArray( "\\SEEN" );
+    return sharedSeen;
+  }
+#endif
+
+  Item::Flags convertedFlags;
+  convertedFlags.reserve( flags.size() );
+  foreach ( const QByteArray &flag, flags ) {
+    if ( valuePool )
+      convertedFlags.insert( valuePool->flagPool.sharedValue( flag ) );
+    else
+      convertedFlags.insert( flag );
+  }
+  return convertedFlags;
+}
+
 void ProtocolHelper::parseItemFetchResult( const QList<QByteArray> &lineTokens, Item &item, ProtocolHelperValuePool *valuePool )
 {
   // create a new item object
@@ -525,26 +565,30 @@ void ProtocolHelper::parseItemFetchResult( const QList<QByteArray> &lineTokens,
       QList<QByteArray> flags;
       ImapParser::parseParenthesizedList( lineTokens[i + 1], flags );
       if ( !flags.isEmpty() ) {
-        Item::Flags convertedFlags;
-        convertedFlags.reserve( flags.size() );
-        foreach ( const QByteArray &flag, flags ) {
-          if ( valuePool )
-            convertedFlags.insert( valuePool->flagPool.sharedValue( flag ) );
-          else
-            convertedFlags.insert( flag );
-        }
-        item.setFlags( convertedFlags );
+        item.setFlags( convertFlags( flags, valuePool ) );
       }
     } else if ( key == "TAGS" ) {
-      ImapSet set;
-      ImapParser::parseSequenceSet( lineTokens[i + 1], set );
       Tag::List tags;
-      Q_FOREACH ( const ImapInterval &interval, set.intervals() ) {
-        Q_ASSERT( interval.hasDefinedBegin() );
-        Q_ASSERT( interval.hasDefinedEnd() );
-        for ( qint64 i = interval.begin(); i <= interval.end(); i++ ) {
-          //TODO use value pool when tag is shared data
-          tags << Tag( i );
+      if ( lineTokens[i + 1].startsWith("(") ) {
+        QList<QByteArray> tagsData;
+        ImapParser::parseParenthesizedList( lineTokens[i + 1], tagsData );
+        Q_FOREACH (const QByteArray &t, tagsData) {
+          QList<QByteArray> tagParts;
+          ImapParser::parseParenthesizedList( t, tagParts );
+          Tag tag;
+          parseTagFetchResult(tagParts, tag);
+          tags << tag;
+        }
+      } else {
+        ImapSet set;
+        ImapParser::parseSequenceSet( lineTokens[i + 1], set );
+        Q_FOREACH ( const ImapInterval &interval, set.intervals() ) {
+          Q_ASSERT( interval.hasDefinedBegin() );
+          Q_ASSERT( interval.hasDefinedEnd() );
+          for ( qint64 i = interval.begin(); i <= interval.end(); i++ ) {
+            //TODO use value pool when tag is shared data
+            tags << Tag( i );
+          }
         }
       }
       item.setTags( tags );
