@@ -223,6 +223,11 @@ public:
     */
     static QByteArray itemFetchScopeToByteArray(const ItemFetchScope &fetchScope);
 
+    /**
+      Converts a given TagFetchScope object into a protocol representation.
+    */
+    static QByteArray tagFetchScopeToByteArray( const TagFetchScope &fetchScope );
+
     /**
       Parses a single line from an item fetch job result into an Item object.
      */
