@@ -34,7 +34,7 @@ using namespace Akonadi;
 class SubscriptionTest : public QObject
 {
   Q_OBJECT
-  private slots:
+  private Q_SLOTS:
     void initTestCase()
     {
       AkonadiTest::checkTestIsIsolated();
