@@ -127,6 +127,12 @@ bool FileStorage::load()
                     VCalFormat vCal;
                     success = vCal.load(calendar(), d->mFileName);
                     productId = vCal.loadedProductId();
+                    if (!success) {
+                        if (vCal.exception()) {
+                            kWarning() << "Exception while importing:" << vCal.exception()->code();
+                        }
+                        return false;
+                    }
                 } else {
                     return false;
                 }
