@@ -90,12 +90,13 @@ void SignatureTester::testTextEditInsertion()
   sig.setEnabledSignature( true );
   sig.setText( QLatin1String("Hello World") );
 
-  // Test inserting signature at start, with seperators
+  // Test inserting signature at start, with seperators. Make sure two new
+  // lines are inserted before the signature
   edit.setPlainText( QLatin1String("Bla Bla") );
   sig.insertIntoTextEdit( Signature::Start, Signature::AddSeparator | Signature::AddNewLines,
                           &edit );
   QVERIFY( edit.textMode() == KRichTextEdit::Plain );
-  QCOMPARE( edit.toPlainText(), QLatin1String( "-- \nHello World\nBla Bla" ) );
+  QCOMPARE( edit.toPlainText(), QLatin1String( "\n\n-- \nHello World\nBla Bla" ) );
 
   // Test inserting signature at end. make sure cursor position is preserved
   edit.clear();
@@ -157,10 +158,10 @@ void SignatureTester::testBug167961()
   sig.insertIntoTextEdit( Signature::End, Signature::AddSeparator | Signature::AddNewLines, &edit );
   QCOMPARE( edit.textCursor().position(), 0 );
 
-  // OTOH, when prepending a sig, the cursor should be at the end
+  // When prepending a sig, the cursor should also be at the start, see bug 211634
   edit.clear();
   sig.insertIntoTextEdit( Signature::Start, Signature::AddSeparator | Signature::AddNewLines, &edit );
-  QCOMPARE( edit.textCursor().position(), 7 ); // "-- \nBLA"
+  QCOMPARE( edit.textCursor().position(), 0 );
 }
 
 // Make writeConfig() public, we need it
