@@ -58,7 +58,7 @@ namespace KTnef {
     @param cal is a pointer to a Calendar object.
     @param h is a pointer to a InvitationFormatterHelp object.
   */
-  KTNEF_EXPORT_DEPRECATED QString formatTNEFInvitation( const QByteArray &tnef,
+  KTNEF_DEPRECATED_EXPORT QString formatTNEFInvitation( const QByteArray &tnef,
                                                         KCal::Calendar *cal,
                                                         KCal::InvitationFormatterHelper *h );
 #endif
