@@ -21,8 +21,6 @@
 #include <akonadi/collectionpathresolver_p.h>
 #include <testattribute.h>
 
-#include <KLocale>
-#include <KLocalizedString>
 
 #include <akonadi/attributefactory.h>
 #include <akonadi/collectioncreatejob.h>
@@ -137,7 +135,7 @@ void FilterActionTest::testMassModifyItems()
       QVERIFY( acc.contains( item ) );
       acc.removeAll( item );
     } else {
-      QVERIFY2( false, "Got bad data \"" + data + '\"' );
+      QVERIFY2( false, QByteArray(QByteArray("Got bad data \"") + data + QByteArray("\"")) );
     }
   }
   QCOMPARE( acc.count(), 0 );
@@ -171,7 +169,7 @@ void FilterActionTest::testMassModifyCollection()
       QVERIFY( acc.contains( item ) );
       acc.removeAll( item );
     } else {
-      QVERIFY2( false, "Got bad data \"" + data + '\"' );
+      QVERIFY2( false, QByteArray(QByteArray("Got bad data \"") + data + QByteArray("\"")) );
     }
   }
   QCOMPARE( acc.count(), 0 );
